.outline-button[data-v-8d870775]{cursor:pointer;display:flex;justify-content:center;align-items:center;padding:4px 8px;gap:8px;border-radius:4px;border:1px solid #d14056;font-weight:500;font-size:12px;color:#d14056;flex-shrink:0;box-shadow:1px 1px 3px #0000000f;background-color:transparent;box-sizing:border-box;height:26px}.outline-button .icon[data-v-8d870775]{height:16px;width:16px}.outline-button .icon[data-v-8d870775] path{fill:#d14056}.outline-button[data-v-8d870775]:hover{background:#f9fafb}.outline-button[data-v-8d870775]:active{background:#f9fafb;box-shadow:inset 1px 1px 2px #0000001a;border-color:transparent}.outline-button.disabled[data-v-8d870775]{cursor:unset;background:#f3f4f6;border:1px solid #bdc3cc;color:#bdc3cc}.outline-button.disabled[data-v-8d870775]:hover,.outline-button.disabled[data-v-8d870775]:active{background:#f3f4f6;box-shadow:none}.outline-button.disabled .icon[data-v-8d870775] path{fill:#bdc3cc}[data-v-24a4c744]:root{--main-font-family: DM Sans, sans-serif}[data-v-24a4c744]:root{--abstra-neutral-color: #bbb;--abstra-primary-color: #ffee56;--abstra-dark-text-color: #1b1b23;--abstra-normal-text-color: #414a58;--abstra-main-color-dark: #343b46;--abstra-main-color-light: #ffd84c;--abstra-secondary-color-dark: #4c5767;--abstra-secondary-color-light: #feab4c;--abstra-background-base: #f9fafb;--abstra-main-color-blue: #d14056}.p-dropdown[data-v-24a4c744]{border-radius:8px;border:1px solid #343b46;background-color:#fff;height:37px;padding:0 10px;align-items:center}.p-dropdown-panel[data-v-24a4c744]{background-color:#fff;padding:10px}.form-auto-fill-btn[data-v-24a4c744]{background-color:#fff!important}[data-v-91fa59aa]:root{--main-font-family: DM Sans, sans-serif}[data-v-91fa59aa]:root{--abstra-neutral-color: #bbb;--abstra-primary-color: #ffee56;--abstra-dark-text-color: #1b1b23;--abstra-normal-text-color: #414a58;--abstra-main-color-dark: #343b46;--abstra-main-color-light: #ffd84c;--abstra-secondary-color-dark: #4c5767;--abstra-secondary-color-light: #feab4c;--abstra-background-base: #f9fafb;--abstra-main-color-blue: #d14056}.p-dropdown[data-v-91fa59aa]{border-radius:8px;border:1px solid #343b46;background-color:#fff;height:37px;padding:0 10px;align-items:center}.p-dropdown-panel[data-v-91fa59aa]{background-color:#fff;padding:10px}.watermark[data-v-91fa59aa]{border-radius:8px 8px 0 0;background-color:#ffffffe6;padding:4px 12px;color:#5a677a;cursor:pointer;text-decoration:none;font-size:11px;display:flex;align-items:center}.watermark .logo[data-v-91fa59aa]{margin-left:10px;margin-right:8px}.watermark b[data-v-91fa59aa]{font-weight:500;color:#5a677a}*[data-v-91fa59aa]{font-family:var(--main-font-family)}.hint[data-v-56c261f3]{position:absolute;top:0;right:0;height:20px;width:20px;cursor:pointer;background-color:#333a;border-radius:50%}.hint path[data-v-56c261f3]{fill:#f5f5f5}.hint .hint-content[data-v-56c261f3]{display:none;background-color:#333d;color:#f5f5f5;padding:3px 5px;border-radius:4px;position:absolute;top:20px;left:20px;z-index:1;max-width:200px;text-align:left;font-size:.8rem;line-height:1.2rem}.hint:hover .hint-content[data-v-56c261f3]{display:block}[data-v-65e4776f]:root{--main-font-family: DM Sans, sans-serif}[data-v-65e4776f]:root{--abstra-neutral-color: #bbb;--abstra-primary-color: #ffee56;--abstra-dark-text-color: #1b1b23;--abstra-normal-text-color: #414a58;--abstra-main-color-dark: #343b46;--abstra-main-color-light: #ffd84c;--abstra-secondary-color-dark: #4c5767;--abstra-secondary-color-light: #feab4c;--abstra-background-base: #f9fafb;--abstra-main-color-blue: #d14056}.p-dropdown[data-v-65e4776f]{border-radius:8px;border:1px solid #343b46;background-color:#fff;height:37px;padding:0 10px;align-items:center}.p-dropdown-panel[data-v-65e4776f]{background-color:#fff;padding:10px}.watermark[data-v-65e4776f]{position:fixed;bottom:0;right:20px}.steps[data-v-65e4776f]{margin:20px auto;max-width:500px}header[data-v-65e4776f]{display:flex;width:100%;box-sizing:border-box;color:var(--font-color, #000)}.span-error[data-v-65e4776f]{color:red}.disabled[data-v-65e4776f]{filter:blur(8px);pointer-events:none;background-color:#e8e8e8}.unsaved-changes[data-v-65e4776f]{position:absolute;z-index:1}.runner[data-v-65e4776f]{position:relative;display:flex;align-items:center;justify-content:center}.runner.preview[data-v-65e4776f]{height:100%}.runner[data-v-65e4776f]:not(.preview){height:100vh}.form[data-v-65e4776f]{padding:2rem 0 3rem}.widget[data-v-65e4776f]{position:relative}.buttons[data-v-65e4776f]{display:flex;flex-direction:row;gap:1rem;justify-content:flex-end;align-items:center;width:100%}.buttons .disabled[data-v-65e4776f]{opacity:.5;cursor:not-allowed}.loading-wrapper[data-v-65e4776f]{display:flex;flex-grow:1;justify-content:center;align-items:center;height:100%;width:100%}.auto-fill-btn[data-v-65e4776f]{position:absolute;bottom:20px;left:20px}
