import{C as r,E as t,K as i,a as f,M as b,c,P as l,R as y,S as g,b as u,T as k,U as p,e as w,l as D}from"./toggleHighContrast.77f3d6d2.js";import"./outputWidgets.0112c29a.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="afc74bd7-9175-4f24-b5f0-92eb6d1394de",e._sentryDebugIdIdentifier="sentry-dbid-afc74bd7-9175-4f24-b5f0-92eb6d1394de")}catch{}})();export{r as CancellationTokenSource,t as Emitter,i as KeyCode,f as KeyMod,b as MarkerSeverity,c as MarkerTag,l as Position,y as Range,g as Selection,u as SelectionDirection,k as Token,p as Uri,w as editor,D as languages};
//# sourceMappingURL=editor.main.f441dfa5.js.map
