import{B as d}from"./BookOutlined.cb11abba.js";import{d as f,b as s,c,w as o,f as l,u as n,di as i,ev as u,ar as b,aD as p,bF as y}from"./outputWidgets.0112c29a.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="705bceac-d4f6-4f0f-af44-ea0bd9bac9e1",t._sentryDebugIdIdentifier="sentry-dbid-705bceac-d4f6-4f0f-af44-ea0bd9bac9e1")}catch{}})();const k=f({__name:"DocsButton",props:{path:{}},setup(t){return(e,r)=>{var a;return s(),c(n(y),{class:"docs-button",href:`https://docs.abstra.io/${(a=e.path)!=null?a:""}`,target:"_blank",type:"link",style:{color:"#d14056"},size:"small"},{icon:o(()=>[l(n(d))]),default:o(()=>[e.$slots.default?i(e.$slots,"default",{key:0}):(s(),u(p,{key:1},[b("Docs")],64))]),_:3},8,["href"])}}});export{k as _};
//# sourceMappingURL=DocsButton.vue_vue_type_script_setup_true_lang.e7adff9f.js.map
