import{u as n}from"./index.4ba7585c.js";import"./outputWidgets.0112c29a.js";import{r as s,w as a}from"./runnerData.82c76ca2.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="9d6255cf-2526-44bf-9efa-66fbc6b52880",t._sentryDebugIdIdentifier="sentry-dbid-9d6255cf-2526-44bf-9efa-66fbc6b52880")}catch{}})();async function i(t){const e=await fetch(`/_pages/${t}`,{headers:n.authHeaders()});if(e.status==404)return null;if(!e.ok)throw new Error(await e.text());const{form:r}=await e.json();return r?s(r):null}async function c(){const t=await fetch("/_workspace");if(t.status!=200)return a({});const e=await t.json();return a(e)}export{i as f,c as g};
//# sourceMappingURL=api.a6dd0453.js.map
