import{F as b}from"./PhArrowSquareOut.vue.dec377b8.js";import{d as k,I as w,b as a,ev as u,c as i,u as t,w as n,ew as v,bg as h,ar as m,aD as C,eE as x,f as d,eG as I,v as D}from"./outputWidgets.0112c29a.js";import"./index.8e0f51a1.js";import"./index.0713bf4b.js";import{A as y}from"./index.0b86c71c.js";import{a as _}from"./Text.7fd7d6e4.js";import{C as B}from"./Card.8672cc2c.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="03b9715d-1930-4110-9819-19619b082207",o._sentryDebugIdIdentifier="sentry-dbid-03b9715d-1930-4110-9819-19619b082207")}catch{}})();const F=k({__name:"HomeContent",props:{loading:{type:Boolean},workspace:{}},emits:["form-click"],setup(o,{emit:r}){const p=o,f=w(()=>{var e,l;return(l=(e=p.workspace)==null?void 0:e.sidebar.filter(s=>s.visible))!=null?l:[]});function g(e){r("form-click",e)}return(e,l)=>{var s;return a(),u("div",{class:"container",style:v({backgroundColor:(s=e.workspace)==null?void 0:s.theme})},[e.loading?(a(),i(t(h),{key:0})):f.value.length===0?(a(),i(t(_),{key:1,type:"secondary",style:{"font-size":"18px"}},{default:n(()=>[m(" There are no public forms available ")]),_:1})):(a(),i(t(y),{key:2,vertical:"",gap:"large",style:{padding:"120px 0"}},{default:n(()=>[(a(!0),u(C,null,x(f.value,c=>(a(),i(t(B),{key:c.id,class:"form-card",onClick:H=>g(c.path)},{default:n(()=>[d(t(y),{gap:"large",align:"center",justify:"space-between"},{default:n(()=>[d(t(_),{style:{"font-size":"18px","font-weight":"500"}},{default:n(()=>[m(I(c.name),1)]),_:2},1024),d(t(b),{color:"#000",width:"20"})]),_:2},1024)]),_:2},1032,["onClick"]))),128))]),_:1}))],4)}}});const j=D(F,[["__scopeId","data-v-e246816b"]]);export{j as H};
//# sourceMappingURL=HomeContent.b3d75ddd.js.map
