import{a as g}from"./asyncComputed.7a4cd8c0.js";import{d as y,eD as _,o as w,u as e,b as f,c as b,ev as x,f as a,w as o,ar as l,bF as h,e as C,eG as I}from"./outputWidgets.0112c29a.js";import{c as p}from"./router.baccdf57.js";import"./index.01d20c53.js";import{O as k}from"./organization.37da7702.js";import{L as v}from"./LoadingContainer.503213ea.js";import{A as D}from"./Title.06b9fc65.js";import{A}from"./index.0b86c71c.js";import{A as B}from"./index.f2d91780.js";import{C as N}from"./Card.8672cc2c.js";import"./Form.f084c7e0.js";import"./hasIn.9ed92b42.js";import"./popupNotifcation.b5f4e167.js";import"./record.63beb4c2.js";import"./pubsub.bc9264fd.js";import"./Text.7fd7d6e4.js";import"./TabPane.1bdf173f.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[n]="518fe7df-373f-4fa8-8ffc-0980fc2a78e4",t._sentryDebugIdIdentifier="sentry-dbid-518fe7df-373f-4fa8-8ffc-0980fc2a78e4")}catch{}})();const z={key:1},M={style:{display:"flex","justify-content":"flex-start","font-size":"24px"}},Y=y({__name:"Billing",setup(t){const r=_().params.organizationId,{loading:c,result:m}=g(()=>k.get(r));w(()=>{location.search.includes("upgrade")&&p.showNewMessage("I want to upgrade my plan")});const u=()=>p.showNewMessage("I want to upgrade my plan");return(V,j)=>e(c)?(f(),b(v,{key:0})):(f(),x("div",z,[a(e(A),{justify:"space-between",align:"center"},{default:o(()=>[a(e(D),{level:3},{default:o(()=>[l("Current plan")]),_:1})]),_:1}),a(e(B),{style:{"margin-top":"0"}}),a(e(N),{style:{width:"300px"},title:"Plan"},{extra:o(()=>[a(e(h),{onClick:u},{default:o(()=>[l("Upgrade")]),_:1})]),default:o(()=>{var s,i,d;return[C("div",M,I((d=(i=(s=e(m))==null?void 0:s.billingMetadata)==null?void 0:i.plan)!=null?d:"No active plan"),1)]}),_:1})]))}});export{Y as default};
//# sourceMappingURL=Billing.048ff1a6.js.map
