import{g as m}from"./api.a6dd0453.js";import{P as f}from"./Passwordless.93d636f4.js";import{a as d}from"./asyncComputed.7a4cd8c0.js";import{W as p}from"./WidgetsFrame.fc702995.js";import{d as u,eJ as l,eD as _,b as i,ev as y,e as b,u as a,c as g,w as h,ex as w,f as v,v as k}from"./outputWidgets.0112c29a.js";import{u as x}from"./index.4ba7585c.js";import"./runnerData.82c76ca2.js";import"./url.3a6cd3b5.js";import"./index.dea2e84d.js";import"./CircularLoading.0dc47467.js";import"./fetch.bbceeb79.js";import"./pubsub.bc9264fd.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="bfeba0ba-84b2-4f20-a205-5e255c5f4920",e._sentryDebugIdIdentifier="sentry-dbid-bfeba0ba-84b2-4f20-a205-5e255c5f4920")}catch{}})();const D={class:"login"},I=u({__name:"Login",setup(e){const t=l(),s=_(),{result:o}=d(m),c=async()=>{await x.signUp();const{redirect:r,...n}=s.query;if(r){t.push({path:r,query:n,params:s.params});return}t.push({name:"playerKanban",query:n})};return(r,n)=>(i(),y("div",null,[b("div",D,[a(o)?(i(),g(p,{key:0,"main-color":a(o).mainColor,theme:a(o).theme,"font-family":a(o).fontFamily,style:{width:"100vw"}},{default:h(()=>[v(f,{onDone:c})]),_:1},8,["main-color","theme","font-family"])):w("",!0)])]))}});const K=k(I,[["__scopeId","data-v-73f41769"]]);export{K as default};
//# sourceMappingURL=Login.8030c643.js.map
