import{d as g,eJ as b,r as y,J as v,b as h,ev as k,f as m,u as t,v as w}from"./outputWidgets.0112c29a.js";import{g as H}from"./api.a6dd0453.js";import{a as p}from"./asyncComputed.7a4cd8c0.js";import{P as I}from"./PlayerNavbar.006e724b.js";import{H as D}from"./HomeContent.b3d75ddd.js";import{u as s}from"./index.4ba7585c.js";import"./runnerData.82c76ca2.js";import"./url.3a6cd3b5.js";import"./PhKanban.vue.6d01f3b2.js";import"./PhSignOut.vue.66e233e9.js";import"./Text.7fd7d6e4.js";import"./index.8e0f51a1.js";import"./Link.28aa17bf.js";import"./Paragraph.a79b7e0d.js";import"./Title.06b9fc65.js";import"./index.47282251.js";import"./PhArrowSquareOut.vue.dec377b8.js";import"./index.0713bf4b.js";import"./Card.8672cc2c.js";import"./TabPane.1bdf173f.js";import"./hasIn.9ed92b42.js";import"./index.0b86c71c.js";import"./fetch.bbceeb79.js";import"./pubsub.bc9264fd.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="12ea9223-e633-42a6-8f7c-ac69f2835308",o._sentryDebugIdIdentifier="sentry-dbid-12ea9223-e633-42a6-8f7c-ac69f2835308")}catch{}})();const x={class:"page"},C=g({__name:"Home",setup(o){const e=b(),r=y(s.getUser()),{result:c,refetch:u}=p(async()=>(await s.allow("kanban")).status==="ALLOWED");v(r,()=>u());const l=({path:a})=>{e.push({name:"form",params:{path:a.split("/")}})},{result:n,loading:d}=p(H),f=a=>{e.push({path:`/${a}`})},_=()=>{s.removeUser(),e.push({name:"playerHome"})};return(a,L)=>{var i;return h(),k("div",x,[m(I,{"runner-data":t(n),"is-kanban-visible":t(c)||!1,"user-email":(i=r.value)==null?void 0:i.claims.email,onNavigate:l,onLogout:_},null,8,["runner-data","is-kanban-visible","user-email"]),m(D,{workspace:t(n),loading:t(d),onFormClick:f},null,8,["workspace","loading"])])}}});const Z=w(C,[["__scopeId","data-v-f12c98c4"]]);export{Z as default};
//# sourceMappingURL=Home.db293c6f.js.map
