.disabled[data-v-e711f126]{opacity:.5;cursor:not-allowed}.preview[data-v-5ba90560]{box-sizing:border-box;overflow:visible;min-width:fit-content;padding:2rem}.buttons[data-v-5ba90560]{display:flex;flex-direction:row;gap:1rem;justify-content:flex-end;align-items:center;width:100%}.disable-events[data-v-5ba90560]{pointer-events:none}
