import{V as i}from"./outputWidgets.0112c29a.js";import{c as d,d as c}from"./index.c7d59a4b.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="2a735922-937a-4064-bf22-89d38929d790",e._sentryDebugIdIdentifier="sentry-dbid-2a735922-937a-4064-bf22-89d38929d790")}catch{}})();const{DatePicker:n,WeekPicker:r,MonthPicker:t,YearPicker:f,TimePicker:m,QuarterPicker:o,RangePicker:a}=d(c),b=i(n,{WeekPicker:r,MonthPicker:t,YearPicker:f,RangePicker:a,TimePicker:m,QuarterPicker:o,install:e=>(e.component(n.name,n),e.component(a.name,a),e.component(t.name,t),e.component(r.name,r),e.component(o.name,o),e)});export{b as D,t as M,o as Q,a as R,r as W};
//# sourceMappingURL=dayjs.f59e94eb.js.map
