import{a as e,A as a,B as s}from"./Text.7fd7d6e4.js";import{A as o}from"./Link.28aa17bf.js";import{A as r}from"./Paragraph.a79b7e0d.js";import{A as i}from"./Title.06b9fc65.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[t]="1f084ef5-87e8-4b0f-b399-35b7e62c8b66",n._sentryDebugIdIdentifier="sentry-dbid-1f084ef5-87e8-4b0f-b399-35b7e62c8b66")}catch{}})();e.Text=a;e.Title=i;e.Paragraph=r;e.Link=o;e.Base=s;e.install=function(n){return n.component(e.name,e),n.component(e.Text.displayName,a),n.component(e.Title.displayName,i),n.component(e.Paragraph.displayName,r),n.component(e.Link.displayName,o),n};
//# sourceMappingURL=index.8e0f51a1.js.map
