import{d as o,b as s,ev as d,e as a,di as r,ez as c,v as l}from"./outputWidgets.0112c29a.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="64b0e53d-db14-49a4-869b-cd7cc182612f",e._sentryDebugIdIdentifier="sentry-dbid-64b0e53d-db14-49a4-869b-cd7cc182612f")}catch{}})();const _={class:"content-layout"},u=o({__name:"ContentLayout",props:{fullWidth:{type:Boolean}},setup(e){return(t,n)=>(s(),d("div",_,[a("div",{class:c(["centered-layout",{"full-width":t.fullWidth}])},[r(t.$slots,"default",{},void 0,!0)],2)]))}});const i=l(u,[["__scopeId","data-v-00ef87a4"]]);export{i as C};
//# sourceMappingURL=ContentLayout.28b2610e.js.map
