import{eZ as t,e_ as r}from"./outputWidgets.0112c29a.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="cf519185-1196-40d3-9ecf-f6ec44923d5e",e._sentryDebugIdIdentifier="sentry-dbid-cf519185-1196-40d3-9ecf-f6ec44923d5e")}catch{}})();function o(e,n){return t(1,arguments),r(e,Date.now(),n)}export{o as f};
//# sourceMappingURL=index.0bd52578.js.map
