import{C as c}from"./ContentLayout.28b2610e.js";import{A as l,K as y,_ as k,E as g}from"./TableView.vue_vue_type_script_setup_true_lang.760ef9ea.js";import{d as _,r as w,b as n,c as i,w as m,L as h,f as s,u as e,ex as d}from"./outputWidgets.0112c29a.js";import{l as v}from"./fetch.bbceeb79.js";import{A as b,T}from"./TabPane.1bdf173f.js";import"./Card.8672cc2c.js";import"./vuedraggable.umd.e21921b1.js";import"./workspaces.09ed9521.js";import"./runnerData.82c76ca2.js";import"./url.3a6cd3b5.js";import"./record.63beb4c2.js";import"./pubsub.bc9264fd.js";import"./asyncComputed.7a4cd8c0.js";import"./scripts.b72aba0d.js";import"./envVars.9350e586.js";import"./api.dc95b689.js";import"./metadata.a1339ff4.js";import"./PhCheckCircle.vue.9254ac51.js";import"./PhScroll.vue.e1ffa452.js";import"./PhWebhooksLogo.vue.179e4e89.js";import"./ant-design.09addbee.js";import"./index.7eba7835.js";import"./Modal.4672b2be.js";import"./Text.7fd7d6e4.js";import"./index.0b86c71c.js";import"./index.84aac883.js";import"./index.0bd52578.js";import"./Paragraph.a79b7e0d.js";import"./index.8e0f51a1.js";import"./Link.28aa17bf.js";import"./Title.06b9fc65.js";import"./index.18d97222.js";import"./CollapsePanel.8c8a75f6.js";import"./index.f2d91780.js";import"./index.58fd6635.js";import"./isNumeric.75337b1e.js";import"./LoadingOutlined.56c05382.js";import"./index.f44237da.js";import"./Form.f084c7e0.js";import"./hasIn.9ed92b42.js";import"./string.01321463.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[t]="71b3bbf5-277d-4fd2-9699-9d5aad980178",o._sentryDebugIdIdentifier="sentry-dbid-71b3bbf5-277d-4fd2-9699-9d5aad980178")}catch{}})();class K{constructor(t=v){this.fetch=t}async fork(t){return(await this.fetch("/_editor/api/stage_runs/fork",{method:"POST",body:JSON.stringify({stage_run_id:t}),headers:{"Content-Type":"application/json"}})).json()}}const ut=_({__name:"WorkflowThreads",setup(o){const t=new g,r=new K,f=new h(l,"kanban-selected-stages"),a=w("kanban");return(S,p)=>(n(),i(c,{"full-width":""},{default:m(()=>[s(e(T),{activeKey:a.value,"onUpdate:activeKey":p[0]||(p[0]=u=>a.value=u)},{default:m(()=>[s(e(b),{key:"kanban",tab:"Kanban View"}),s(e(b),{key:"table",tab:"Table View"})]),_:1},8,["activeKey"]),a.value==="kanban"?(n(),i(y,{key:0,"kanban-repository":e(t),"kanban-stages-storage":e(f),"stage-run-repository":e(r)},null,8,["kanban-repository","kanban-stages-storage","stage-run-repository"])):d("",!0),a.value==="table"?(n(),i(k,{key:1,"kanban-repository":e(t)},null,8,["kanban-repository"])):d("",!0)]),_:1}))}});export{ut as default};
//# sourceMappingURL=WorkflowThreads.13c0bc03.js.map
