import{cv as n}from"./outputWidgets.0112c29a.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="aad7c62f-b55a-4b44-8239-deba5bac4b02",e._sentryDebugIdIdentifier="sentry-dbid-aad7c62f-b55a-4b44-8239-deba5bac4b02")}catch{}})();const o=(e,r,d)=>{n.error({message:e,description:r,onClick:d})};export{o as p};
//# sourceMappingURL=popupNotifcation.b5f4e167.js.map
