import"./outputWidgets.0112c29a.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="05854090-4975-457f-8444-453af1a77163",e._sentryDebugIdIdentifier="sentry-dbid-05854090-4975-457f-8444-453af1a77163")}catch{}})();const o=e=>{try{return new URL(e),!0}catch{return!1}},f=(e,r)=>{if(!Object.keys(r).length)return e;const t=new URL(e),n=new URLSearchParams(t.search);return Object.entries(r).forEach(([s,a])=>{t.searchParams.delete(s),n.set(s,a)}),`${t.origin}${t.pathname}?${n.toString()}`};export{o as i,f as m};
//# sourceMappingURL=url.3a6cd3b5.js.map
