import{d as $,O as A,f as o,a6 as _,Y as M,r as h,ag as w,aq as T,S,Q as k,e8 as N,dk as D}from"./outputWidgets.0112c29a.js";import{C as P}from"./Form.f084c7e0.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},c=new Error().stack;c&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[c]="3a8dc284-38d2-4540-a01a-81b3f76ee1d4",t._sentryDebugIdIdentifier="sentry-dbid-3a8dc284-38d2-4540-a01a-81b3f76ee1d4")}catch{}})();const K=()=>({avatar:_.any,description:_.any,prefixCls:String,title:_.any}),q=$({compatConfig:{MODE:3},name:"AListItemMeta",props:K(),displayName:"AListItemMeta",__ANT_LIST_ITEM_META:!0,slots:Object,setup(t,c){let{slots:e}=c;const{prefixCls:a}=A("list",t);return()=>{var n,v,f,y,p,l;const s=`${a.value}-item-meta`,i=(n=t.title)!==null&&n!==void 0?n:(v=e.title)===null||v===void 0?void 0:v.call(e),r=(f=t.description)!==null&&f!==void 0?f:(y=e.description)===null||y===void 0?void 0:y.call(e),m=(p=t.avatar)!==null&&p!==void 0?p:(l=e.avatar)===null||l===void 0?void 0:l.call(e),b=o("div",{class:`${a.value}-item-meta-content`},[i&&o("h4",{class:`${a.value}-item-meta-title`},[i]),r&&o("div",{class:`${a.value}-item-meta-description`},[r])]);return o("div",{class:s},[m&&o("div",{class:`${a.value}-item-meta-avatar`},[m]),(i||r)&&b])}}}),F=Symbol("ListContextKey");var Q=globalThis&&globalThis.__rest||function(t,c){var e={};for(var a in t)Object.prototype.hasOwnProperty.call(t,a)&&c.indexOf(a)<0&&(e[a]=t[a]);if(t!=null&&typeof Object.getOwnPropertySymbols=="function")for(var n=0,a=Object.getOwnPropertySymbols(t);n<a.length;n++)c.indexOf(a[n])<0&&Object.prototype.propertyIsEnumerable.call(t,a[n])&&(e[a[n]]=t[a[n]]);return e};const V=()=>({prefixCls:String,extra:_.any,actions:_.array,grid:Object,colStyle:{type:Object,default:void 0}}),B=$({compatConfig:{MODE:3},name:"AListItem",inheritAttrs:!1,Meta:q,props:V(),slots:Object,setup(t,c){let{slots:e,attrs:a}=c;const{itemLayout:n,grid:v}=M(F,{grid:h(),itemLayout:h()}),{prefixCls:f}=A("list",t),y=()=>{var l;const s=((l=e.default)===null||l===void 0?void 0:l.call(e))||[];let i;return s.forEach(r=>{N(r)&&!D(r)&&(i=!0)}),i&&s.length>1},p=()=>{var l,s;const i=(l=t.extra)!==null&&l!==void 0?l:(s=e.extra)===null||s===void 0?void 0:s.call(e);return n.value==="vertical"?!!i:!y()};return()=>{var l,s,i,r,m;const{class:b}=a,E=Q(a,["class"]),u=f.value,g=(l=t.extra)!==null&&l!==void 0?l:(s=e.extra)===null||s===void 0?void 0:s.call(e),x=(i=e.default)===null||i===void 0?void 0:i.call(e);let d=(r=t.actions)!==null&&r!==void 0?r:w((m=e.actions)===null||m===void 0?void 0:m.call(e));d=d&&!Array.isArray(d)?[d]:d;const I=d&&d.length>0&&o("ul",{class:`${u}-item-action`,key:"actions"},[d.map((L,O)=>o("li",{key:`${u}-item-action-${O}`},[L,O!==d.length-1&&o("em",{class:`${u}-item-action-split`},null)]))]),j=v.value?"div":"li",C=o(j,S(S({},E),{},{class:k(`${u}-item`,{[`${u}-item-no-flex`]:!p()},b)}),{default:()=>[n.value==="vertical"&&g?[o("div",{class:`${u}-item-main`,key:"content"},[x,I]),o("div",{class:`${u}-item-extra`,key:"extra"},[g])]:[x,I,T(g,{key:"extra"})]]});return v.value?o(P,{flex:1,style:t.colStyle},{default:()=>[C]}):C}}});export{B as A,q as I,F as L};
//# sourceMappingURL=Item.8743502e.js.map
