import{B as n,R as d}from"./Badge.de399662.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="a850b65f-a6f5-45c4-9f52-6022943d293c",e._sentryDebugIdIdentifier="sentry-dbid-a850b65f-a6f5-45c4-9f52-6022943d293c")}catch{}})();n.install=function(e){return e.component(n.name,n),e.component(d.name,d),e};
//# sourceMappingURL=index.6ac5e5f8.js.map
