import{u as o,a as l}from"./index.4ba7585c.js";import{d as w,r as u,b as n,ev as h,f as b,u as t,e as K,c as d,ex as f,L as x}from"./outputWidgets.0112c29a.js";import{P as A}from"./PlayerNavbar.006e724b.js";import{K as B,_ as D,A as I,P as L}from"./TableView.vue_vue_type_script_setup_true_lang.760ef9ea.js";import{a as N}from"./asyncComputed.7a4cd8c0.js";import{g as S}from"./api.a6dd0453.js";import{A as P}from"./index.28948779.js";import"./fetch.bbceeb79.js";import"./pubsub.bc9264fd.js";import"./PhKanban.vue.6d01f3b2.js";import"./PhSignOut.vue.66e233e9.js";import"./Text.7fd7d6e4.js";import"./index.8e0f51a1.js";import"./Link.28aa17bf.js";import"./Paragraph.a79b7e0d.js";import"./Title.06b9fc65.js";import"./index.47282251.js";import"./vuedraggable.umd.e21921b1.js";import"./workspaces.09ed9521.js";import"./runnerData.82c76ca2.js";import"./url.3a6cd3b5.js";import"./record.63beb4c2.js";import"./scripts.b72aba0d.js";import"./envVars.9350e586.js";import"./api.dc95b689.js";import"./metadata.a1339ff4.js";import"./PhCheckCircle.vue.9254ac51.js";import"./PhScroll.vue.e1ffa452.js";import"./PhWebhooksLogo.vue.179e4e89.js";import"./ant-design.09addbee.js";import"./index.7eba7835.js";import"./Modal.4672b2be.js";import"./index.0b86c71c.js";import"./index.84aac883.js";import"./index.0bd52578.js";import"./index.18d97222.js";import"./CollapsePanel.8c8a75f6.js";import"./index.f2d91780.js";import"./index.58fd6635.js";import"./isNumeric.75337b1e.js";import"./Card.8672cc2c.js";import"./TabPane.1bdf173f.js";import"./hasIn.9ed92b42.js";import"./LoadingOutlined.56c05382.js";import"./index.f44237da.js";import"./Form.f084c7e0.js";import"./string.01321463.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="bdef9f86-34be-4e8d-914b-b601f071db70",e._sentryDebugIdIdentifier="sentry-dbid-bdef9f86-34be-4e8d-914b-b601f071db70")}catch{}})();const T={style:{padding:"20px"}},De=w({__name:"Threads",setup(e){const a=new L(o),s=new x(I,"kanban-selected-stages"),c=u(o.getUser()),g=["Kanban","Table view"],r=u("Kanban"),{result:y}=N(S),v=({path:i})=>{l.push({name:"form",params:{path:i.split("/")}})},k=()=>{o.removeUser(),l.push({name:"playerHome"})};return(i,m)=>{var p;return n(),h("div",null,[b(A,{"runner-data":t(y),"show-kanban":!1,"is-kanban-visible":!1,"user-email":(p=c.value)==null?void 0:p.claims.email,onLogout:k,onNavigate:v},null,8,["runner-data","user-email"]),K("div",T,[b(t(P),{value:r.value,"onUpdate:value":m[0]||(m[0]=_=>r.value=_),options:g,style:{"margin-bottom":"16px"}},null,8,["value"]),r.value==="Kanban"?(n(),d(B,{key:0,"kanban-repository":t(a),"kanban-stages-storage":t(s)},null,8,["kanban-repository","kanban-stages-storage"])):f("",!0),r.value==="Table view"?(n(),d(D,{key:1,"kanban-repository":t(a)},null,8,["kanban-repository"])):f("",!0)])])}}});export{De as default};
//# sourceMappingURL=Threads.a6cd7abd.js.map
