import{d as t,b as o,ev as s,f as d,u as r,bg as _,v as c}from"./outputWidgets.0112c29a.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="99a3052e-9e9a-42a3-8f94-6164a25e1cb2",e._sentryDebugIdIdentifier="sentry-dbid-99a3052e-9e9a-42a3-8f94-6164a25e1cb2")}catch{}})();const i={class:"centered"},f=t({__name:"LoadingContainer",setup(e){return(n,a)=>(o(),s("div",i,[d(r(_))]))}});const u=c(f,[["__scopeId","data-v-1da18eee"]]);export{u as L};
//# sourceMappingURL=LoadingContainer.503213ea.js.map
